==> 3050-PostSoftwareAssuranceTool-1.1.0-1.zip: ReplyListDlg.h <==
#if !defined(AFX_REPLYLISTDLG_H__0A5F9345_F415_4F0E_A0FB_BFF0DAA428A7__INCLUDED_)
#define AFX_REPLYLISTDLG_H__0A5F9345_F415_4F0E_A0FB_BFF0DAA428A7__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// ReplyListDlg.h : header file
//

#include "StdAfx.h"

/////////////////////////////////////////////////////////////////////////////
// CReplyListDlg dialog

class CReplyListDlg : public CDialog
{
// Construction
public:
	CReplyListDlg(CWnd* pParent = NULL);   // standard constructor
	void SetSocket( CClientSocket* pClientSocket );
	void SetWnd(HWND hwnd);
	void DrawBackground ( CDC* pDC );
	void SetWindowPosition ( CRect rtPosition );

// Dialog Data
	HWND			m_pHwnd;
	int				m_nListIndex;
	CString			m_strProgramKey;
	CClientSocket*	m_pClientSocket;
	CBitmap			m_bmBackground;
	CPoint			m_ptPosition;
	BOOL			m_bIsFirst;
	//enum { IDD = IDD_REPLY_LIST_DIALOG 140 };

	//{{AFX_DATA(CReplyListDlg)
	enum { IDD = 140 };

	YButton	m_btnClose;
	YButton	m_btnRegisterReply;
	YButton	m_btnRemoveReply;
	YButton	m_btnRightList;
	YButton	m_btnLeftList;
	CEdit	m_edtReadReply;
	CEdit	m_edtWriteReply;
	CListCtrl	m_listReplyList;
	CString	m_strWriteReply;
	//}}AFX_DATA


// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CReplyListDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
protected:

	// Generated message map functions
	//{{AFX_MSG(CReplyListDlg)
	afx_msg void OnButtonLeftMove();
	afx_msg void OnButtonRegisterRelpy();
	afx_msg void OnButtonRemoveReply();
	afx_msg void OnButtonRightMove();
	virtual BOOL OnInitDialog();
	afx_msg void OnPaint();
	afx_msg void OnButtonClose();
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_REPLYLISTDLG_H__0A5F9345_F415_4F0E_A0FB_BFF0DAA428A7__INCLUDED_)

==> 3050-PostSoftwareAssuranceTool-1.2.2-1.zip: ReplyListDlg.h <==
#if !defined(AFX_REPLYLISTDLG_H__0A5F9345_F415_4F0E_A0FB_BFF0DAA428A7__INCLUDED_)
#define AFX_REPLYLISTDLG_H__0A5F9345_F415_4F0E_A0FB_BFF0DAA428A7__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000
// ReplyListDlg.h : header file
//

#include "StdAfx.h"

/////////////////////////////////////////////////////////////////////////////
// CReplyListDlg dialog

class CReplyListDlg : public CDialog
{
// Construction
public:
	CReplyListDlg(CWnd* pParent = NULL);   // standard constructor
	void SetSocket( CClientSocket* pClientSocket );
	void SetWnd(HWND hwnd);
	void DrawBackground ( CDC* pDC );
	void SetWindowPosition ( CRect rtPosition );
	void GivenReceiveData ( KReplyListPacket* pPacket );
	CString ParsingDate( char* pszDate );
	void InitListCtrl();
	void ProcessReplyRegisterAck( int nResult );
	void ProcessReplyRemoveAck( int nResult );

// Dialog Data
	KReplyRegisterPacket	m_ReplyRegisterPacket;
	KReplyRemovePacket		m_ReplyRemovePacket;
	HWND			m_pHwnd;
	int				m_nListNum;
	int				m_nListIndex;
	int				m_nRemoveReplyId;
	CString			m_strProgramKey;
	CString			m_strUserId;
	CClientSocket*	m_pClientSocket;
	CBitmap			m_bmBackground;
	CPoint			m_ptPosition;

	BOOL			m_bIsFirst;
	//enum { IDD = IDD_REPLY_LIST_DIALOG 140 };

	//{{AFX_DATA(CReplyListDlg)
	enum { IDD = 140 };
	CStatic	m_staticReadReply;
	YButton	m_btnClose;
	YButton	m_btnRegisterReply;
	YButton	m_btnRemoveReply;
	YButton	m_btnRightList;
	YButton	m_btnLeftList;
	CEdit	m_edtReadReply;
	CEdit	m_edtWriteReply;
	CListCtrl	m_listReplyList;
	CString	m_strWriteReply;
	//}}AFX_DATA


// Overrides
	// ClassWizard generated virtual function overrides
	//{{AFX_VIRTUAL(CReplyListDlg)
	protected:
	virtual void DoDataExchange(CDataExchange* pDX);    // DDX/DDV support
	//}}AFX_VIRTUAL

// Implementation
protected:

	// Generated message map functions
	//{{AFX_MSG(CReplyListDlg)
	afx_msg void OnButtonLeftMove();
	afx_msg void OnButtonRegisterRelpy();
	afx_msg void OnButtonRemoveReply();
	afx_msg void OnButtonRightMove();
	virtual BOOL OnInitDialog();
	afx_msg void OnPaint();
	afx_msg void OnButtonClose();
	afx_msg void OnClickListReply(NMHDR* pNMHDR, LRESULT* pResult);
	afx_msg HBRUSH OnCtlColor(CDC* pDC, CWnd* pWnd, UINT nCtlColor);
	//}}AFX_MSG
	DECLARE_MESSAGE_MAP()
};

//{{AFX_INSERT_LOCATION}}
// Microsoft Visual C++ will insert additional declarations immediately before the previous line.

#endif // !defined(AFX_REPLYLISTDLG_H__0A5F9345_F415_4F0E_A0FB_BFF0DAA428A7__INCLUDED_)
